# Stubs for networkx.algorithms.vitality (Python 3.5)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

def closeness_vitality(G, node: Optional[Any] = ..., weight: Optional[Any] = ..., wiener_index: Optional[Any] = ...): ...
