# Stubs for networkx.algorithms.flow.preflowpush (Python 3.5)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

def preflow_push(G, s, t, capacity: str = ..., residual: Optional[Any] = ..., global_relabel_freq: int = ..., value_only: bool = ...): ...
