# Stubs for galaxy.util.odict (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional
from six.moves import UserDict

dict_alias = ...  # type: Any

class odict(UserDict):
    def __init__(self, dict: Optional[Any] = ...) -> None: ...
    def __delitem__(self, key): ...
    def __setitem__(self, key, item): ...
    def clear(self): ...
    def copy(self): ...
    def items(self): ...
    def keys(self): ...
    def popitem(self): ...
    def setdefault(self, key, failobj: Optional[Any] = ...): ...
    def update(self, dict): ...
    def values(self): ...
    def iterkeys(self): ...
    def itervalues(self): ...
    def iteritems(self): ...
    def __iter__(self): ...
    def reverse(self): ...
    def insert(self, index, key, item): ...
