# Stubs for galaxy.tools.verify.asserts.text (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

def assert_has_text(output, text): ...
def assert_not_has_text(output, text): ...
def assert_has_line(output, line): ...
def assert_has_text_matching(output, expression): ...
def assert_has_line_matching(output, expression): ...
