# Stubs for galaxy (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

PROJECT_NAME = ...  # type: str
PROJECT_OWNER = ...  # type: str
PROJECT_USERAME = ...  # type: str
PROJECT_URL = ...  # type: str
PROJECT_AUTHOR = ...  # type: str
PROJECT_EMAIL = ...  # type: str
RAW_CONTENT_URL = ...  # type: Any
