# Stubs for galaxy.util.oset (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional
import collections

class OrderedSet(collections.MutableSet):
    end = ...  # type: Any
    map = ...  # type: Any
    def __init__(self, iterable: Optional[Any] = ...) -> None: ...
    def __len__(self): ...
    def __contains__(self, key): ...
    def add(self, key): ...
    def discard(self, key): ...
    def __iter__(self): ...
    def __reversed__(self): ...
    def pop(self, last: bool = ...): ...
    def __eq__(self, other): ...
