# Stubs for galaxy.tools.parser.output_collection_def (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

DEFAULT_EXTRA_FILENAME_PATTERN = ...  # type: str
DEFAULT_SORT_BY = ...  # type: str
DEFAULT_SORT_COMP = ...  # type: str
NAMED_PATTERNS = ...  # type: Any
INPUT_DBKEY_TOKEN = ...  # type: str
LEGACY_DEFAULT_DBKEY = ...  # type: Any

def dataset_collector_descriptions_from_elem(elem, legacy: bool = ...): ...
def dataset_collector_descriptions_from_list(discover_datasets_dicts): ...

class DatasetCollectionDescription:
    pattern = ...  # type: Any
    default_dbkey = ...  # type: Any
    default_ext = ...  # type: Any
    default_visible = ...  # type: Any
    directory = ...  # type: Any
    assign_primary_output = ...  # type: Any
    sort_reverse = ...  # type: bool
    sort_key = ...  # type: Any
    sort_comp = ...  # type: Any
    def __init__(self, **kwargs) -> None: ...

DEFAULT_DATASET_COLLECTOR_DESCRIPTION = ...  # type: Any
