# Stubs for galaxy.tools.linters.command (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

def lint_command(tool_xml, lint_ctx): ...
def get_command(tool_xml): ...
