# Stubs for galaxy.jobs.metrics.instrumenters (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any
from ...metrics import formatting as formatting

INSTRUMENT_FILE_PREFIX = ...  # type: str

class InstrumentPlugin:
    formatter = ...  # type: Any
    @property
    def plugin_type(self): ...
    def pre_execute_instrument(self, job_directory): ...
    def post_execute_instrument(self, job_directory): ...
    def job_properties(self, job_id, job_directory): ...
