# Stubs for galaxy.util.submodules (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

log = ...  # type: Any

def submodules(module): ...
