# Stubs for networkx.algorithms.flow.shortestaugmentingpath (Python 3.5)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from .utils import *
from typing import Any, Optional

def shortest_augmenting_path(G, s, t, capacity: str = ..., residual: Optional[Any] = ..., value_only: bool = ..., two_phase: bool = ..., cutoff: Optional[Any] = ...): ...
