# Stubs for galaxy.util.properties (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional
from six.moves.configparser import ConfigParser

def find_config_file(default, old_default, explicit, cwd: Optional[Any] = ...): ...
def load_app_properties(kwds: Any = ..., ini_file: Optional[Any] = ..., ini_section: str = ..., config_prefix: str = ...): ...

class NicerConfigParser(ConfigParser):
    filename = ...  # type: Any
    def __init__(self, filename, *args, **kw) -> None: ...
    read_file = ...  # type: Any
    def defaults(self): ...
    class InterpolateWrapper:
        def __init__(self, original) -> None: ...
        def __getattr__(self, name): ...
        def before_get(self, parser, section, option, value, defaults): ...
