# Stubs for galaxy.tools.locations (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

class ToolLocationResolver:
    def scheme(self): ...
    def get_tool_source_path(self, uri_like): ...
