# Stubs for galaxy.util.plugin_config (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

yaml = ...  # type: Any

def plugins_dict(module, plugin_type_identifier): ...
def load_plugins(plugins_dict, plugin_source, extra_kwds: Any = ...): ...
def plugin_source_from_path(path): ...
