# Stubs for galaxy.objectstore.s3_multipart_upload (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

boto = ...  # type: Any

def map_wrap(f): ...
def mp_from_ids(s3server, mp_id, mp_keyname, mp_bucketname): ...
def transfer_part(s3server, mp_id, mp_keyname, mp_bucketname, i, part): ...
def multipart_upload(s3server, bucket, s3_key_name, tarball, mb_size): ...
def multimap(cores: Optional[Any] = ...): ...
