# Stubs for galaxy.util.image_util (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any
from PIL import Image as PIL

PIL = ...  # type: Any
log = ...  # type: Any

def image_type(filename): ...
def check_image_type(filename, types): ...
def get_image_ext(file_path): ...
