# Stubs for galaxy.tools.parser (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from .factory import get_input_source as get_input_source, get_tool_source as get_tool_source
from .interface import ToolSource as ToolSource
from .output_objects import ToolOutputCollectionPart as ToolOutputCollectionPart
