# Stubs for networkx.algorithms.centrality.katz (Python 3.5)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

def katz_centrality(G, alpha: float = ..., beta: float = ..., max_iter: int = ..., tol: float = ..., nstart: Optional[Any] = ..., normalized: bool = ..., weight: Optional[Any] = ...): ...
def katz_centrality_numpy(G, alpha: float = ..., beta: float = ..., normalized: bool = ..., weight: Optional[Any] = ...): ...
