# Stubs for galaxy.tools.verify.asserts (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

log = ...  # type: Any
assertion_module_names = ...  # type: Any
assertion_modules = ...  # type: Any
full_assertion_module_name = ...  # type: Any
assertion_module = ...  # type: Any

def verify_assertions(data, assertion_description_list): ...
def verify_assertion(data, assertion_description): ...
