# Stubs for galaxy.tools.cwl.representation (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

log = ...  # type: Any
NOT_PRESENT = ...  # type: Any
GALAXY_TO_CWL_TYPES = ...  # type: Any

def to_cwl_job(tool, param_dict, local_working_directory): ...
def to_galaxy_parameters(tool, as_dict): ...
