# Stubs for prov.serializers.provn (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from prov.serializers import Serializer
from typing import Any

__email__: str
logger: Any

class ProvNSerializer(Serializer):
    def serialize(self, stream: Any, **kwargs: Any) -> None: ...
    def deserialize(self, stream: Any, **kwargs: Any) -> None: ...
