# Stubs for galaxy.tools.linters.xml_order (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

TAG_ORDER = ...  # type: Any
DATASOURCE_TAG_ORDER = ...  # type: Any

def lint_xml_order(tool_xml, lint_ctx): ...
