# Stubs for galaxy.exceptions.error_codes (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

UNKNOWN_ERROR_MESSAGE = ...  # type: str

class ErrorCode:
    code = ...  # type: Any
    default_error_message = ...  # type: Any
    def __init__(self, code, default_error_message) -> None: ...
    def __int__(self): ...

error_codes_json = ...  # type: Any
name = ...  # type: Any
error_code_obj = ...  # type: Any
