# Stubs for galaxy.util.lazy_process (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class LazyProcess:
    command_and_args = ...  # type: Any
    thread_lock = ...  # type: Any
    allow_process_request = ...  # type: bool
    process = ...  # type: Any
    def __init__(self, command_and_args) -> None: ...
    def start_process(self): ...
    def shutdown(self): ...
    @property
    def running(self): ...

class NoOpLazyProcess:
    def start_process(self): ...
    def shutdown(self): ...
    @property
    def running(self): ...
