# Stubs for galaxy.util.hash_util (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional
import hashlib as hashlib

sha1 = ...  # type: Any
sha = ...  # type: Any
md5 = ...  # type: Any

def new_secure_hash(text_type: Optional[Any] = ...): ...
def hmac_new(key, value): ...
def is_hashable(value): ...
