# Stubs for galaxy.tools.lint (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any
from .parser import get_tool_source as get_tool_source

LEVEL_ALL = ...  # type: str
LEVEL_WARN = ...  # type: str
LEVEL_ERROR = ...  # type: str

def lint_tool_source(tool_source, level: Any = ..., fail_level: Any = ..., extra_modules: Any = ..., skip_types: Any = ...): ...
def lint_xml(tool_xml, level: Any = ..., fail_level: Any = ..., extra_modules: Any = ..., skip_types: Any = ...): ...
def lint_tool_source_with(lint_context, tool_source, extra_modules: Any = ...): ...
def lint_xml_with(lint_context, tool_xml, extra_modules: Any = ...): ...

class LintContext:
    skip_types = ...  # type: Any
    level = ...  # type: Any
    found_errors = ...  # type: bool
    found_warns = ...  # type: bool
    def __init__(self, level, skip_types: Any = ...) -> None: ...
    printed_linter_info = ...  # type: bool
    valid_messages = ...  # type: Any
    info_messages = ...  # type: Any
    warn_messages = ...  # type: Any
    error_messages = ...  # type: Any
    def lint(self, name, lint_func, lint_target): ...
    def valid(self, message, *args): ...
    def info(self, message, *args): ...
    def error(self, message, *args): ...
    def warn(self, message, *args): ...
    def failed(self, fail_level): ...
