# Stubs for galaxy.tools.verify.asserts.tabular (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

def get_first_line(output): ...
def assert_has_n_columns(output, n, sep: str = ...): ...
