# Stubs for galaxy.util.expressions (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional
from collections import MutableMapping

class ExpressionContext(MutableMapping):
    dict = ...  # type: Any
    parent = ...  # type: Any
    def __init__(self, dict, parent: Optional[Any] = ...) -> None: ...
    def __delitem__(self, key): ...
    def __iter__(self): ...
    def __len__(self): ...
    def __getitem__(self, key): ...
    def __setitem__(self, key, value): ...
    def __contains__(self, key): ...
    def __nonzero__(self): ...
