# Stubs for galaxy.tools.loader_directory (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

def find_possible_tools_from_path(path, recursive: bool = ..., enable_beta_formats: bool = ...): ...
def load_tool_sources_from_path(path, load_exception_handler: Any = ..., recursive: bool = ..., register_load_errors: bool = ...): ...
def load_tool_elements_from_path(path, load_exception_handler: Any = ..., recursive: bool = ..., register_load_errors: bool = ...): ...
def is_tool_load_error(obj): ...
def looks_like_a_tool_xml(path): ...
def is_a_yaml_with_class(path, classes): ...
def looks_like_a_tool_yaml(path): ...
def looks_like_a_cwl_artifact(path, classes: Optional[Any] = ...): ...
def looks_like_a_tool_cwl(path): ...
