# Stubs for prov.identifier (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

__email__: str

class Identifier:
    def __init__(self, uri: Any) -> None: ...
    @property
    def uri(self): ...
    def __eq__(self, other: Any): ...
    def __hash__(self): ...
    def provn_representation(self): ...

class QualifiedName(Identifier):
    def __init__(self, namespace: Any, localpart: Any) -> None: ...
    @property
    def namespace(self): ...
    @property
    def localpart(self): ...
    def __hash__(self): ...
    def provn_representation(self): ...

class Namespace:
    def __init__(self, prefix: Any, uri: Any) -> None: ...
    @property
    def uri(self): ...
    @property
    def prefix(self): ...
    def contains(self, identifier: Any): ...
    def qname(self, identifier: Any): ...
    def __eq__(self, other: Any): ...
    def __ne__(self, other: Any): ...
    def __hash__(self): ...
    def __getitem__(self, localpart: Any): ...
