# Stubs for prov.serializers.provjson (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from prov.constants import *
import json
from prov.serializers import Error, Serializer
from typing import Any

logger: Any
__email__: str

class ProvJSONException(Error): ...

class AnonymousIDGenerator:
    def __init__(self) -> None: ...
    def get_anon_id(self, obj: Any, local_prefix: str = ...): ...

LITERAL_XSDTYPE_MAP: Any

class ProvJSONSerializer(Serializer):
    def serialize(self, stream: Any, **kwargs: Any) -> None: ...
    def deserialize(self, stream: Any, **kwargs: Any): ...

class ProvJSONEncoder(json.JSONEncoder):
    def default(self, o: Any): ...

class ProvJSONDecoder(json.JSONDecoder):
    def decode(self, s: Any, *args: Any, **kwargs: Any): ...

def valid_qualified_name(bundle: Any, value: Any): ...
def encode_json_document(document: Any): ...
def encode_json_container(bundle: Any): ...
def decode_json_document(content: Any, document: Any) -> None: ...
def decode_json_container(jc: Any, bundle: Any) -> None: ...
def encode_json_representation(value: Any): ...
def decode_json_representation(literal: Any, bundle: Any): ...
def literal_json_representation(literal: Any): ...
