# Stubs for galaxy.jobs.metrics.collectl.cli (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class CollectlCli:
    mode = ...  # type: Any
    command_args = ...  # type: Any
    def __init__(self, **kwargs) -> None: ...
    def build_command_line(self): ...
    def run(self, stdout: Any = ..., stderr: Any = ...): ...
