# Stubs for galaxy.util.specs (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

def to_str_or_none(value): ...
def to_bool_or_none(value): ...
def to_bool(value): ...
def to_float_or_none(value): ...
def is_in(*args): ...
