# Stubs for prov.serializers.provxml (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from prov.constants import *
import prov.identifier
from typing import Any, Optional

__email__: str
logger: Any
FULL_NAMES_MAP: Any
FULL_PROV_RECORD_IDS_MAP: Any
XML_XSD_URI: str

class ProvXMLException(prov.Error): ...

class ProvXMLSerializer(prov.serializers.Serializer):
    def serialize(self, stream: Any, force_types: bool = ..., **kwargs: Any) -> None: ...
    def serialize_bundle(self, bundle: Any, element: Optional[Any] = ..., force_types: bool = ...): ...
    def deserialize(self, stream: Any, **kwargs: Any): ...
    def deserialize_subtree(self, xml_doc: Any, bundle: Any): ...

def xml_qname_to_QualifiedName(element: Any, qname_str: Any): ...
