# Stubs for networkx.algorithms.centrality.betweenness (Python 3.5)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

def betweenness_centrality(G, k: Optional[Any] = ..., normalized: bool = ..., weight: Optional[Any] = ..., endpoints: bool = ..., seed: Optional[Any] = ...): ...
def edge_betweenness_centrality(G, k: Optional[Any] = ..., normalized: bool = ..., weight: Optional[Any] = ..., seed: Optional[Any] = ...): ...
def edge_betweenness(G, k: Optional[Any] = ..., normalized: bool = ..., weight: Optional[Any] = ..., seed: Optional[Any] = ...): ...
