# Stubs for galaxy.jobs.metrics.formatting (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

class JobMetricFormatter:
    def format(self, key, value): ...

def seconds_to_str(value): ...
