# Stubs for galaxy.util.heartbeat (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any
import threading

def get_current_thread_object_dict(): ...

class Heartbeat(threading.Thread):
    config = ...  # type: Any
    should_stop = ...  # type: bool
    period = ...  # type: Any
    fname = ...  # type: Any
    file = ...  # type: Any
    fname_nonsleeping = ...  # type: Any
    file_nonsleeping = ...  # type: Any
    pid = ...  # type: Any
    nonsleeping_heartbeats = ...  # type: Any
    wait_event = ...  # type: Any
    def __init__(self, config, name: str = ..., period: int = ..., fname: str = ...) -> None: ...
    def run(self): ...
    def open_logs(self): ...
    def close_logs(self): ...
    def dump(self): ...
    def shutdown(self): ...
    def thread_is_sleeping(self, last_stack_frame): ...
    def get_interesting_stack_frame(self, stack_frames): ...
    def print_nonsleeping(self, threads_object_dict): ...
    def dump_signal_handler(self, signum, frame): ...
