# Stubs for galaxy.util.sockets (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

def unused_port(range: Optional[Any] = ...): ...
