from base64 import urlsafe_b64decode as urlsafe_b64decode
from typing import Any, Optional

SCHEME: str

def arcp_uuid(uuid: Any, path: str = ..., query: Optional[Any] = ..., fragment: Optional[Any] = ...): ...
def arcp_random(path: str = ..., query: Optional[Any] = ..., fragment: Optional[Any] = ..., uuid: Optional[Any] = ...): ...
def arcp_location(location: Any, path: str = ..., query: Optional[Any] = ..., fragment: Optional[Any] = ..., namespace: Any = ...): ...
def arcp_name(name: Any, path: str = ..., query: Optional[Any] = ..., fragment: Optional[Any] = ...): ...
def arcp_hash(bytes: bytes = ..., path: str = ..., query: Optional[Any] = ..., fragment: Optional[Any] = ..., hash: Optional[Any] = ...): ...
