# Stubs for networkx.algorithms.centrality.current_flow_betweenness_subset (Python 3.5)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from networkx.algorithms.centrality.flow_matrix import *
from typing import Any, Optional

def current_flow_betweenness_centrality_subset(G, sources, targets, normalized: bool = ..., weight: Optional[Any] = ..., dtype: Any = ..., solver: str = ...): ...
def edge_current_flow_betweenness_centrality_subset(G, sources, targets, normalized: bool = ..., weight: Optional[Any] = ..., dtype: Any = ..., solver: str = ...): ...
