# Stubs for galaxy.tools.deps.resolvers.resolver_mixins (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any
from ..brew_exts import build_env_statements as build_env_statements, DEFAULT_HOMEBREW_ROOT as DEFAULT_HOMEBREW_ROOT, recipe_cellar_path as recipe_cellar_path
from ..resolvers import Dependency as Dependency, NullDependency as NullDependency

class UsesHomebrewMixin: ...
class UsesToolDependencyDirMixin: ...
class UsesInstalledRepositoriesMixin: ...

class HomebrewDependency(Dependency):
    commands = ...  # type: Any
    def __init__(self, commands, exact: bool = ...) -> None: ...
    @property
    def exact(self): ...
    def shell_commands(self, requirement): ...
