# Stubs for galaxy.tools.linters.tests (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from ..lint_util import is_datasource as is_datasource

def lint_tsts(tool_xml, lint_ctx): ...
