# Stubs for galaxy.tools.deps.mulled.mulled_build_files (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional
from collections import namedtuple

def main(argv: Optional[Any] = ...): ...

_Line = namedtuple('_Line', ['targets', 'image_build', 'name_override'])
