# Stubs for galaxy.tools.verify (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional
from .asserts import verify_assertions as verify_assertions
from .test_data import TestDataResolver as TestDataResolver

log = ...  # type: Any
DEFAULT_TEST_DATA_RESOLVER = ...  # type: Any

def verify(item_label, output_content, attributes, filename: Optional[Any] = ..., get_filename: Optional[Any] = ..., keep_outputs_dir: Optional[Any] = ..., verify_extra_files: Optional[Any] = ...): ...
def make_temp_fname(fname: Optional[Any] = ...): ...
def check_command(command, description): ...
def files_diff(file1, file2, attributes: Optional[Any] = ...): ...
def files_re_match(file1, file2, attributes: Optional[Any] = ...): ...
def files_re_match_multiline(file1, file2, attributes: Optional[Any] = ...): ...
def files_contains(file1, file2, attributes: Optional[Any] = ...): ...
