# Stubs for galaxy.tools.deps.brew_util (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any
from ..deps import brew_exts as brew_exts

DEFAULT_TAP = ...  # type: str

class HomebrewRecipe:
    recipe = ...  # type: Any
    version = ...  # type: Any
    tap = ...  # type: Any
    def __init__(self, recipe, version, tap) -> None: ...

def requirements_to_recipes(requirements): ...
def requirement_to_recipe(requirement): ...
def requirements_to_recipe_contexts(requirements, brew_context): ...
