# Stubs for galaxy.util.compression_utils (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from .checkers import is_bz2 as is_bz2, is_gzip as is_gzip

def get_fileobj(filename, mode: str = ..., gzip_only: bool = ..., bz2_only: bool = ..., zip_only: bool = ...): ...
