# Stubs for galaxy.tools.linters.general (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

ERROR_VERSION_MSG = ...  # type: str
VALID_VERSION_MSG = ...  # type: str
ERROR_NAME_MSG = ...  # type: str
VALID_NAME_MSG = ...  # type: str
ERROR_ID_MSG = ...  # type: str
VALID_ID_MSG = ...  # type: str
PROFILE_PATTERN = ...  # type: Any
PROFILE_INFO_DEFAULT_MSG = ...  # type: str
PROFILE_INFO_SPECIFIED_MSG = ...  # type: str
PROFILE_INVALID_MSG = ...  # type: str
lint_tool_types = ...  # type: Any

def lint_general(tool_source, lint_ctx): ...
