# Stubs for galaxy.util.xml_macros (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

REQUIRED_PARAMETER = ...  # type: Any

def load(path): ...
def template_macro_params(root): ...
def raw_tool_xml_tree(path): ...
def imported_macro_paths(root): ...

class XmlMacroDef:
    elements = ...  # type: Any
    parameters = ...  # type: Any
    def __init__(self, el) -> None: ...
    def macro_tokens(self, expand_el): ...
