# Stubs for galaxy.tools.deps.views (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

class DependencyResolversView:
    def __init__(self, app) -> None: ...
    def index(self): ...
    def show(self, index): ...
    def reload(self): ...
    def manager_requirements(self): ...
    def resolver_requirements(self, index): ...
    def manager_dependency(self, **kwds): ...
    def resolver_dependency(self, index, **kwds): ...
    def show_dependencies(self, tool_requirements_d, installed_tool_dependencies: Optional[Any] = ...): ...
    def uninstall_dependencies(self, index: Optional[Any] = ..., **payload): ...
    @property
    def unused_dependency_paths(self): ...
    def remove_unused_dependency_paths(self, envs): ...
    def install_dependencies(self, requirements): ...
    def install_dependency(self, index: Optional[Any] = ..., **payload): ...
    @property
    def installable_resolvers(self): ...
    @property
    def uninstallable_resolvers(self): ...
    @property
    def tool_ids_by_requirements(self): ...
    @property
    def toolbox_requirements_status(self): ...
    def get_requirements_status(self, tool_requirements_d, installed_tool_dependencies: Optional[Any] = ...): ...
    def clean(self, index: Optional[Any] = ..., **kwds): ...
