# Stubs for galaxy.tools.deps.mulled.mulled_build_tool (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

def main(argv: Optional[Any] = ...): ...
def requirements_to_mulled_targets(requirements): ...
