# Stubs for galaxy.tools.locations.file (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from ..locations import ToolLocationResolver as ToolLocationResolver

class HttpToolResolver(ToolLocationResolver):
    scheme = ...  # type: str
    def get_tool_source_path(self, uri_like): ...
