# Stubs for galaxy.tools.cwl.runtime_actions (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

def handle_outputs(job_directory: Optional[Any] = ...): ...
