# Stubs for networkx.algorithms.boundary (Python 3.5)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

def edge_boundary(G, nbunch1, nbunch2: Optional[Any] = ..., data: bool = ..., keys: bool = ..., default: Optional[Any] = ...): ...
def node_boundary(G, nbunch1, nbunch2: Optional[Any] = ...): ...
