# Stubs for galaxy.tools.linters.cwl (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

lint_tool_types = ...  # type: Any

def lint_cwl_validation(tool_source, lint_ctx): ...
def lint_new_draft(tool_source, lint_ctx): ...
def lint_docker_image(tool_source, lint_ctx): ...
def lint_description(tool_source, lint_ctx): ...
