# Stubs for galaxy.tools.linters.stdio (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from .command import get_command as get_command

def lint_stdio(tool_source, lint_ctx): ...
