# Stubs for galaxy.tools.locations.dockstore (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any
from ..locations import ToolLocationResolver

class DockStoreResolver(ToolLocationResolver):
    scheme = ...  # type: str
    def get_tool_source_path(self, uri_like): ...

class _Ga4ghToolClient:
    base_url = ...  # type: Any
    def __init__(self, base_url: str = ...) -> None: ...
    def get_tools(self): ...
    def get_tool(self, tool_id): ...
    def get_tool_version(self, tool_id, version: str = ...): ...
    def get_tool_descriptor(self, tool_id, version: str = ..., tool_type: str = ...): ...
    def get_tool_cwl(self, tool_id, version: str = ..., as_string: bool = ...): ...
