# Stubs for networkx.algorithms.connectivity.cuts (Python 3.5)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from networkx.algorithms.flow import edmonds_karp
from typing import Any, Optional

default_flow_func = edmonds_karp

def minimum_st_edge_cut(G, s, t, flow_func: Optional[Any] = ..., auxiliary: Optional[Any] = ..., residual: Optional[Any] = ...): ...
def minimum_st_node_cut(G, s, t, flow_func: Optional[Any] = ..., auxiliary: Optional[Any] = ..., residual: Optional[Any] = ...): ...
def minimum_node_cut(G, s: Optional[Any] = ..., t: Optional[Any] = ..., flow_func: Optional[Any] = ...): ...
def minimum_edge_cut(G, s: Optional[Any] = ..., t: Optional[Any] = ..., flow_func: Optional[Any] = ...): ...
