# Stubs for galaxy.tools.deps.dockerfiles (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional
from ..deps import commands as commands
from ..deps import docker_util as docker_util
from ..deps.containers import docker_cache_path as docker_cache_path
from ..deps.requirements import parse_requirements_from_xml as parse_requirements_from_xml
from ...tools import loader_directory as loader_directory

log = ...  # type: Any

def docker_host_args(**kwds): ...
def dockerfile_build(path, dockerfile: Optional[Any] = ..., error: Any = ..., **kwds): ...
