# Stubs for prov.graph (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

__email__: str
INFERRED_ELEMENT_CLASS: Any

def prov_to_graph(prov_document: Any): ...
def graph_to_prov(g: Any): ...
