# Stubs for networkx.generators.ego (Python 3.5)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

def ego_graph(G, n, radius: int = ..., center: bool = ..., undirected: bool = ..., distance: Optional[Any] = ...): ...
