# Stubs for galaxy.jobs.metrics.collectl.subsystems (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

class CollectlSubsystem:
    @property
    def command_line_arg(self): ...
    @property
    def name(self, job_directory): ...

class ProcessesSubsystem(CollectlSubsystem):
    command_line_arg = ...  # type: str
    name = ...  # type: str

class CpuSubsystem(CollectlSubsystem):
    command_line_arg = ...  # type: str
    name = ...  # type: str

class DiskSubsystem(CollectlSubsystem):
    command_line_arg = ...  # type: str
    name = ...  # type: str

class NetworkSubsystem(CollectlSubsystem):
    command_line_arg = ...  # type: str
    name = ...  # type: str

class EnvironmentSubsystem(CollectlSubsystem):
    command_line_arg = ...  # type: str
    name = ...  # type: str

class MemorySubsystem(CollectlSubsystem):
    command_line_arg = ...  # type: str
    name = ...  # type: str

def get_subsystem(name): ...
