# Stubs for galaxy.tools.deps.resolvers.brewed_tool_shed_packages (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any
from xml.etree import ElementTree as ET
from .resolver_mixins import UsesHomebrewMixin, UsesInstalledRepositoriesMixin, UsesToolDependencyDirMixin
from ..resolvers import DependencyResolver

class HomebrewToolShedDependencyResolver(DependencyResolver, UsesHomebrewMixin, UsesToolDependencyDirMixin, UsesInstalledRepositoriesMixin):
    resolver_type = ...  # type: str
    def __init__(self, dependency_manager, **kwds) -> None: ...
    def resolve(self, requirement, **kwds): ...

class RawDependencies:
    root = ...  # type: Any
    dependencies = ...  # type: Any
    def __init__(self, dependencies_file) -> None: ...
    def find(self, package_name, package_version): ...

class RawDependency:
    dependencies = ...  # type: Any
    package_el = ...  # type: Any
    repository_el = ...  # type: Any
    def __init__(self, dependencies, package_el, repository_el) -> None: ...
    @property
    def repository_owner(self): ...
    @property
    def repository_name(self): ...
    @property
    def package_name(self): ...
    @property
    def package_version(self): ...
