# Stubs for prov (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

class Error(Exception): ...

def read(source: Any, format: Optional[Any] = ...): ...

# Names in __all__ with no definition:
#   model
