# Stubs for galaxy.util.sleeper (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class Sleeper:
    condition = ...  # type: Any
    def __init__(self) -> None: ...
    def sleep(self, seconds): ...
    def wake(self): ...
