# Stubs for galaxy.util.simplegraph (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

class SimpleGraphNode:
    index = ...  # type: Any
    data = ...  # type: Any
    def __init__(self, index, **data) -> None: ...

class SimpleGraphEdge:
    source_index = ...  # type: Any
    target_index = ...  # type: Any
    data = ...  # type: Any
    def __init__(self, source_index, target_index, **data) -> None: ...

class SimpleGraph:
    nodes = ...  # type: Any
    edges = ...  # type: Any
    def __init__(self, nodes: Optional[Any] = ..., edges: Optional[Any] = ...) -> None: ...
    def add_node(self, node_id, **data): ...
    def add_edge(self, source_id, target_id, **data): ...
    def gen_node_dicts(self): ...
    def gen_edge_dicts(self): ...
    def as_dict(self): ...
