# Stubs for prov.serializers.provrdf (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from prov.serializers import Error, Serializer
from typing import Any, Optional

__email__: str

class ProvRDFException(Error): ...

class AnonymousIDGenerator:
    def __init__(self) -> None: ...
    def get_anon_id(self, obj: Any, local_prefix: str = ...): ...

LITERAL_XSDTYPE_MAP: Any

def attr2rdf(attr: Any): ...
def valid_qualified_name(bundle: Any, value: Any, xsd_qname: bool = ...): ...

class ProvRDFSerializer(Serializer):
    def serialize(self, stream: Optional[Any] = ..., rdf_format: str = ..., **kwargs: Any) -> None: ...
    document: Any = ...
    def deserialize(self, stream: Any, rdf_format: str = ..., **kwargs: Any): ...
    def valid_identifier(self, value: Any): ...
    def encode_rdf_representation(self, value: Any): ...
    def decode_rdf_representation(self, literal: Any, graph: Any): ...
    def encode_document(self, document: Any): ...
    def encode_container(self, bundle: Any, container: Optional[Any] = ..., identifier: Optional[Any] = ...): ...
    def decode_document(self, content: Any, document: Any) -> None: ...
    def decode_container(self, graph: Any, bundle: Any) -> None: ...

def walk(children: Any, level: int = ..., path: Optional[Any] = ..., usename: bool = ...): ...
def literal_rdf_representation(literal: Any): ...
