# Stubs for galaxy.tools.deps.resolvers.homebrew (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any
from .resolver_mixins import UsesHomebrewMixin
from ..resolvers import DependencyResolver

class HomebrewDependencyResolver(DependencyResolver, UsesHomebrewMixin):
    resolver_type = ...  # type: str
    versionless = ...  # type: Any
    prefer_version = ...  # type: Any
    def __init__(self, dependency_manager, **kwds) -> None: ...
    def resolve(self, requirement, **kwds): ...
