# Stubs for galaxy.util.dictifiable (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

class Dictifiable:
    def to_dict(self, view: str = ..., value_mapper: Optional[Any] = ...): ...
