# Stubs for galaxy.tools.cwl.cwltool_deps (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any
from cwltool import main as main, workflow as workflow, process as process, pathmapper as pathmapper
from cwltool import load_tool as load_tool
import shellescape as shellescape
import schema_salad as schema_salad
from schema_salad import ref_resolver as ref_resolver

main = ...  # type: Any
workflow = ...  # type: Any
process = ...  # type: Any
pathmapper = ...  # type: Any
load_tool = ...  # type: Any
shellescape = ...  # type: Any
schema_salad = ...  # type: Any
ref_resolver = ...  # type: Any
needs_shell_quoting = ...  # type: Any

def ensure_cwltool_available(): ...
