# Stubs for prov.constants (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

__email__: str
XSD: Any
PROV: Any
XSI: Any
PROV_ENTITY: Any
PROV_ACTIVITY: Any
PROV_GENERATION: Any
PROV_USAGE: Any
PROV_COMMUNICATION: Any
PROV_START: Any
PROV_END: Any
PROV_INVALIDATION: Any
PROV_DERIVATION: Any
PROV_AGENT: Any
PROV_ATTRIBUTION: Any
PROV_ASSOCIATION: Any
PROV_DELEGATION: Any
PROV_INFLUENCE: Any
PROV_BUNDLE: Any
PROV_ALTERNATE: Any
PROV_SPECIALIZATION: Any
PROV_MENTION: Any
PROV_MEMBERSHIP: Any
PROV_N_MAP: Any
ADDITIONAL_N_MAP: Any
PROV_BASE_CLS: Any
PROV_ATTR_ENTITY: Any
PROV_ATTR_ACTIVITY: Any
PROV_ATTR_TRIGGER: Any
PROV_ATTR_INFORMED: Any
PROV_ATTR_INFORMANT: Any
PROV_ATTR_STARTER: Any
PROV_ATTR_ENDER: Any
PROV_ATTR_AGENT: Any
PROV_ATTR_PLAN: Any
PROV_ATTR_DELEGATE: Any
PROV_ATTR_RESPONSIBLE: Any
PROV_ATTR_GENERATED_ENTITY: Any
PROV_ATTR_USED_ENTITY: Any
PROV_ATTR_GENERATION: Any
PROV_ATTR_USAGE: Any
PROV_ATTR_SPECIFIC_ENTITY: Any
PROV_ATTR_GENERAL_ENTITY: Any
PROV_ATTR_ALTERNATE1: Any
PROV_ATTR_ALTERNATE2: Any
PROV_ATTR_BUNDLE: Any
PROV_ATTR_INFLUENCEE: Any
PROV_ATTR_INFLUENCER: Any
PROV_ATTR_COLLECTION: Any
PROV_ATTR_TIME: Any
PROV_ATTR_STARTTIME: Any
PROV_ATTR_ENDTIME: Any
PROV_ATTRIBUTE_QNAMES: Any
PROV_ATTRIBUTE_LITERALS: Any
PROV_ATTRIBUTES: Any
PROV_RECORD_ATTRIBUTES: Any
PROV_RECORD_IDS_MAP: Any
PROV_ID_ATTRIBUTES_MAP: Any
PROV_ATTRIBUTES_ID_MAP: Any
PROV_TYPE: Any
PROV_LABEL: Any
PROV_VALUE: Any
PROV_LOCATION: Any
PROV_ROLE: Any
PROV_QUALIFIEDNAME: Any
XSD_ANYURI: Any
XSD_QNAME: Any
XSD_DATETIME: Any
XSD_TIME: Any
XSD_DATE: Any
XSD_STRING: Any
XSD_BOOLEAN: Any
XSD_INTEGER: Any
XSD_LONG: Any
XSD_INT: Any
XSD_SHORT: Any
XSD_BYTE: Any
XSD_NONNEGATIVEINTEGER: Any
XSD_UNSIGNEDLONG: Any
XSD_UNSIGNEDINT: Any
XSD_UNSIGNEDSHORT: Any
XSD_UNSIGNEDBYTE: Any
XSD_POSITIVEINTEGER: Any
XSD_NONPOSITIVEINTEGER: Any
XSD_NEGATIVEINTEGER: Any
XSD_FLOAT: Any
XSD_DOUBLE: Any
XSD_DECIMAL: Any
