# Stubs for galaxy.tools.fetcher (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class ToolLocationFetcher:
    resolver_classes = ...  # type: Any
    def __init__(self) -> None: ...
    def to_tool_path(self, path_or_uri_like, **kwds): ...
