# Stubs for galaxy.tools.parser.util (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from .interface import ToolStdioExitCode as ToolStdioExitCode
from .interface import ToolStdioRegex as ToolStdioRegex

def error_on_exit_code(): ...
def aggressive_error_checks(): ...
