# Stubs for galaxy.tools.deps.commands (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional
from galaxy.util import which as which

def redirecting_io(sys: Any = ...): ...
def redirect_aware_commmunicate(p, sys: Any = ...): ...
def shell(cmds, env: Optional[Any] = ..., **kwds): ...
def shell_process(cmds, env: Optional[Any] = ..., **kwds): ...
def execute(cmds): ...
def argv_to_str(command_argv, quote: bool = ...): ...
def download_command(url, to: Any = ..., quote_url: bool = ...): ...

class CommandLineException(Exception):
    command = ...  # type: Any
    stdout = ...  # type: Any
    stderr = ...  # type: Any
    returncode = ...  # type: Any
    message = ...  # type: Any
    def __init__(self, command, stdout, stderr, returncode) -> None: ...
