# Stubs for galaxy.objectstore.rods (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional
from posixpath import basename as path_basename
from posixpath import dirname as path_dirname
from posixpath import join as path_join
from ..objectstore import DiskObjectStore as DiskObjectStore, local_extra_dirs as local_extra_dirs

irods = ...  # type: Any
IRODS_IMPORT_MESSAGE = ...  # type: str
log = ...  # type: Any

class IRODSObjectStore(DiskObjectStore):
    cache_path = ...  # type: Any
    default_resource = ...  # type: Any
    root_collection_path = ...  # type: Any
    root_collection = ...  # type: Any
    def __init__(self, config, file_path: Optional[Any] = ..., extra_dirs: Optional[Any] = ...) -> None: ...
    def exists(self, obj, **kwargs): ...
    def create(self, obj, **kwargs): ...
    def empty(self, obj, **kwargs): ...
    def size(self, obj, **kwargs): ...
    def delete(self, obj, entire_dir: bool = ..., **kwargs): ...
    def get_data(self, obj, start: int = ..., count: int = ..., **kwargs): ...
    def get_filename(self, obj, **kwargs): ...
    def update_from_file(self, obj, file_name: Optional[Any] = ..., create: bool = ..., **kwargs): ...
    def get_object_url(self, obj, **kwargs): ...
    def get_store_usage_percent(self): ...

def rods_connect(): ...
