# Stubs for galaxy.tools.cwl (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from .cwltool_deps import needs_shell_quoting as needs_shell_quoting, shellescape as shellescape
from .parser import tool_proxy as tool_proxy, workflow_proxy as workflow_proxy
from .representation import to_cwl_job as to_cwl_job, to_galaxy_parameters as to_galaxy_parameters
from .runtime_actions import handle_outputs as handle_outputs
