# Stubs for networkx.algorithms.assortativity.pairs (Python 3.5)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

def node_attribute_xy(G, attribute, nodes: Optional[Any] = ...): ...
def node_degree_xy(G, x: str = ..., y: str = ..., weight: Optional[Any] = ..., nodes: Optional[Any] = ...): ...
