# Stubs for galaxy.tools.verify.asserts.xml (Python 3.4)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

def to_xml(output): ...
def xml_find_text(output, path): ...
def xml_find(output, path): ...
def assert_is_valid_xml(output): ...
def assert_has_element_with_path(output, path): ...
def assert_has_n_elements_with_path(output, path, n): ...
def assert_element_text_matches(output, path, expression): ...
def assert_element_text_is(output, path, text): ...
def assert_attribute_matches(output, path, attribute, expression): ...
def assert_attribute_is(output, path, attribute, text): ...
def assert_element_text(output, path, verify_assertions_function, children): ...
